# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kvstore.proto
import sys

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_b = sys.version_info[0] < 3 and (
    lambda x: x
) or (lambda x: x.encode('latin1'))
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='kvstore.proto',
    package='',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b('\n\rkvstore.proto\"\"\n\x04KvTx\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"$\n\x06KVPair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"(\n\x0e\x41\x63\x63ountKvState\x12\x16\n\x05store\x18\x01 \x03(\x0b\x32\x07.KVPairb\x06proto3'),
)


_KVTX = _descriptor.Descriptor(
    name='KvTx',
    full_name='KvTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='KvTx.key', index=0,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='KvTx.value', index=1,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=17,
    serialized_end=51,
)


_KVPAIR = _descriptor.Descriptor(
    name='KVPair',
    full_name='KVPair',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='KVPair.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name='value', full_name='KVPair.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=53,
    serialized_end=89,
)


_ACCOUNTKVSTATE = _descriptor.Descriptor(
    name='AccountKvState',
    full_name='AccountKvState',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='store', full_name='AccountKvState.store', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR,
        ),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=91,
    serialized_end=131,
)

_ACCOUNTKVSTATE.fields_by_name['store'].message_type = _KVPAIR
DESCRIPTOR.message_types_by_name['KvTx'] = _KVTX
DESCRIPTOR.message_types_by_name['KVPair'] = _KVPAIR
DESCRIPTOR.message_types_by_name['AccountKvState'] = _ACCOUNTKVSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KvTx = _reflection.GeneratedProtocolMessageType(
    'KvTx', (_message.Message,), dict(
        DESCRIPTOR=_KVTX,
        __module__='kvstore_pb2',
        # @@protoc_insertion_point(class_scope:KvTx)
    ),
)
_sym_db.RegisterMessage(KvTx)

KVPair = _reflection.GeneratedProtocolMessageType(
    'KVPair', (_message.Message,), dict(
        DESCRIPTOR=_KVPAIR,
        __module__='kvstore_pb2',
        # @@protoc_insertion_point(class_scope:KVPair)
    ),
)
_sym_db.RegisterMessage(KVPair)

AccountKvState = _reflection.GeneratedProtocolMessageType(
    'AccountKvState', (_message.Message,), dict(
        DESCRIPTOR=_ACCOUNTKVSTATE,
        __module__='kvstore_pb2',
        # @@protoc_insertion_point(class_scope:AccountKvState)
    ),
)
_sym_db.RegisterMessage(AccountKvState)


# @@protoc_insertion_point(module_scope)
